@@ -43,7 +43,7 @@ setMethodS3("extractMatrix", "AffymetrixCelFile", function(this, cells=NULL, ...
     rm(srt);
     verbose && exit(verbose);
   } else {
-    o <- seq(length=ncells);
+    o <- seq_len(ncells);
   }
   
   verbose && enter(verbose, "Retrieving data");
