@@ -57,12 +57,12 @@ setMethodS3("extractTheta", "ChipEffectSet", function(this, units=NULL, groups=N
   # Extract the thetas
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
   nbrOfGroups <- length(groups);
-  nbrOfArrays <- nbrOfArrays(this);
+  nbrOfArrays <- length(this);
   dim <- c(nbrOfUnits, nbrOfGroups, nbrOfArrays);
   dimnames <- list(NULL, NULL, getNames(this));
   naValue <- as.double(NA);
   theta <- array(naValue, dim=dim, dimnames=dimnames);
-  for (kk in seq(length=nbrOfArrays)) {
+  for (kk in seq_len(nbrOfArrays)) {
     ce <- getFile(this, kk);
     thetaKK <- extractTheta(ce, units=ugcMap, groups=groups, 
                                                  verbose=less(verbose, 5));
@@ -93,9 +93,7 @@ setMethodS3("extractTheta", "SnpChipEffectSet", function(this, groups=NULL, ...)
     groups <- 1:maxNbrOfGroups;
   }
 
-  theta <- NextMethod("extractTheta", this, groups=groups, ...);
-
-  theta;
+  NextMethod("extractTheta", groups=groups);
 })
 
 
@@ -112,9 +110,7 @@ setMethodS3("extractTheta", "CnChipEffectSet", function(this, groups=NULL, ...)
     groups <- 1:maxNbrOfGroups;
   }
 
-  theta <- NextMethod("extractTheta", this, groups=groups, ...);
-
-  theta;
+  NextMethod("extractTheta", groups=groups);
 })
 
 
