@@ -1,4 +1,5 @@
 setMethodS3("extractAlleleSet", "SnpChipEffectSet", function(this, units=NULL, sortUnits=TRUE, transform=log2, ..., verbose=FALSE) {
+  require("Biobase") || throw("Package not loaded: Biobase");
   require("oligo") || throw("Package not loaded: oligo");
 
   # Assert oligo version
@@ -193,6 +194,9 @@ setMethodS3("extractAlleleSet", "SnpChipEffectSet", function(this, units=NULL, s
 
 ############################################################################
 # HISTORY:
+# 2012-09-01
+# o ROBUSTNESS: extractAlleleSet() for SnpChipEffectSet would throw an
+#   exception if the 'Biobase' package was not loaded.
 # 2010-05-11
 # o BUG FIX: Too early rm(units) in extractAlleleSet().
 # 2010-05-09
