@@ -1,13 +1,57 @@
-#  doGCRMA() runs in bounded memory and replicates the results of
-#  @see "gcrma::gcrma" in the \pkg{gcrma} package with great precision.
-# \references{
-#  [1] Z. Wu, R. Irizarry, R. Gentleman, F.M. Murillo & F. Spencer, A Model Based Background Adjustment for Oligonucleotide Expression Arrays, JASA, 2004.
+###########################################################################/**
+# @RdocDefault doGCRMA
+# @alias doGCRMA.AffymetrixCelSet
+#
+# @title "Robust Multichip Analysis (GCRMA)"
+#
+# \description{
+#  @get "title" based on [1].
+#  The algorithm is processed in bounded memory, meaning virtually
+#  any number of arrays can be analyzed on also very limited computer
+#  systems.
+#  The method replicates the results of @see "gcrma::gcrma"
+#  (package \pkg{gcrma}) with great precision.
 # }
-
-setMethodS3("doGCRMA", "AffymetrixCelSet", function(csR, arrays=NULL, type=c("fullmodel", "affinities"), ..., uniquePlm=FALSE, drop=TRUE, ram=NULL, verbose=FALSE) {
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+#
+# \usage{
+#   \method{doGCRMA}{AffymetrixCelSet}(csR, arrays=NULL, type=c("fullmodel", "affinities"), uniquePlm=FALSE, drop=TRUE, verbose=FALSE, ...)
+#   \method{doGCRMA}{default}(dataSet, ..., verbose=FALSE)
+# }
+#
+# \arguments{
+#  \item{csR, dataSet}{An @see "AffymetrixCelSet" (or the name of an @see "AffymetrixCelSet").}
+#  \item{arrays}{A @integer @vector specifying the subset of arrays
+#   to run RMA on.  If @NULL, all arrays are considered.}
+#  \item{type}{A @character string specifying what type of model to
+#   use for the GCRMA background correction.
+#   For more details, see @see "GcRmaBackgroundCorrection".}
+#  \item{uniquePlm}{If @TRUE, the log-additive probe-summarization model
+#   is done on probeset with \emph{unique} sets of probes.
+#   If @FALSE, the summarization is done on "as-is" probesets as
+#   specified by the CDF.}
+#  \item{drop}{If @TRUE, the RMA summaries are returned, otherwise
+#   a named @list of all intermediate and final results.}
+#  \item{verbose}{See @see "Verbose".}
+#  \item{...}{Additional arguments used to set up @see "AffymetrixCelSet" (when argument \code{dataSet} is specified).}
+# }
+#
+# \value{
+#   Returns a named @list, iff \code{drop == FALSE}, otherwise
+#   only @see "ChipEffectSet" object (containing the RMA summaries).
+# }
+#
+# \references{
+#  [1] Z. Wu, R. Irizarry, R. Gentleman, F.M. Murillo & F. Spencer.
+#      \emph{A Model Based Background Adjustment for Oligonucleotide
+#      Expression Arrays}, JASA, 2004.\cr
+# }
+#
+# @author "HB"
+#*/###########################################################################
+setMethodS3("doGCRMA", "AffymetrixCelSet", function(csR, arrays=NULL, type=c("fullmodel", "affinities"), uniquePlm=FALSE, drop=TRUE, verbose=FALSE, ...) {
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'csR':
   className <- "AffymetrixCelSet";
   if (!inherits(csR, className)) {
@@ -41,18 +85,25 @@ setMethodS3("doGCRMA", "AffymetrixCelSet", function(csR, arrays=NULL, type=c("fu
   verbose && cat(verbose, "arrays:");
   verbose && str(verbose, arraysTag);
   verbose && cat(verbose, "Fit PLM on unique probe sets: ", uniquePlm);
-  verbose && cat(verbose, "ram: ", ram);
 
-
-  # List of objects to be returned
-  res <- list();
-  if (!drop) {
-    res <- c(res, list(csR=csR));
+  # Backward compatibility
+  ram <- list(...)$ram;
+  if (!is.null(ram)) {
+    ram <- Arguments$getDouble(ram, range=c(0,Inf));
+    verbose && cat(verbose, "ram: ", ram);
+    warning("Argument 'ram' of doRMA() is deprecated. Instead use setOption(aromaSettings, \"memory/ram\", ram).");
+    oram <- setOption(aromaSettings, "memory/ram", ram);
+    on.exit({
+      setOption(aromaSettings, "memory/ram", oram);
+    });
   }
 
   verbose && cat(verbose, "Data set");
   verbose && print(verbose, csR);
 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  # Subset?
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (!is.null(arrays)) {
     verbose && enter(verbose, "GCRMA/Extracting subset of arrays");
     csR <- extract(csR, arrays);
@@ -61,9 +112,59 @@ setMethodS3("doGCRMA", "AffymetrixCelSet", function(csR, arrays=NULL, type=c("fu
     verbose && exit(verbose);
   }
 
+
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  # Check if the final results are already available?
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  if (drop) {
+    verbose && enter(verbose, "Checking whether final results are available or not");
+
+    # The name, tags and chip type and array names of the results to look for
+    dataSet <- getFullName(csR);
+    cdf <- getCdf(csR);
+    chipType <- getChipType(cdf, fullname=FALSE);
+
+    # The fullnames of all arrays that should exist
+    fullnames <- getFullNames(csR);
+
+    # gcRMA tags
+    tags <- c("GRBC"); # Same tags regardless of 'type' argument
+    tags <- c(tags, "QN");
+    tags <- c(tags, "RMA,oligo");
+
+    # Try to load the final TCN data set
+    ces <- tryCatch({
+      cesT <- ChipEffectSet$byName(dataSet, tags=tags, chipType=chipType);
+      extract(cesT, fullnames, onMissing="error");
+    }, error=function(ex) { NULL });
+
+    # Done?
+    if (!is.null(ces)) {
+      verbose && cat(verbose, "Already done.");
+      verbose && print(verbose, ces);
+      verbose && exit(verbose);
+      verbose && exit(verbose);
+      return(ces);
+    } # if (!is.null(ces))
+
+    verbose && exit(verbose);
+  } # if (drop)
+
+
+
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  # RMA
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  # List of objects to be returned
+  res <- list();
+  if (!drop) {
+    res <- c(res, list(csR=csR));
+  }
+
+
   verbose && enter(verbose, "GCRMA/Background correction");
 
-  # Currently, you must use the standard CDF file. 
+  # Currently, you must use the standard CDF file.
   cdf <- getCdf(csR);
   chipTypeS <- getChipType(cdf, fullname=FALSE);
   cdfS <- AffymetrixCdfFile$byChipType(chipTypeS);
@@ -139,7 +240,7 @@ setMethodS3("doGCRMA", "AffymetrixCelSet", function(csR, arrays=NULL, type=c("fu
   plm <- RmaPlm(csN, flavor="oligo");
   verbose && print(verbose, plm);
   if (length(findUnitsTodo(plm)) > 0) {
-    units <- fit(plm, ram=ram, verbose=verbose);
+    units <- fit(plm, verbose=verbose);
     verbose && str(verbose, units);
     rm(units);
   }
@@ -168,7 +269,7 @@ setMethodS3("doGCRMA", "AffymetrixCelSet", function(csR, arrays=NULL, type=c("fu
 }) # doGCRMA()
 
 
-setMethodS3("doGCRMA", "character", function(dataSet, ..., verbose=FALSE) {
+setMethodS3("doGCRMA", "default", function(dataSet, ..., verbose=FALSE) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -201,8 +302,10 @@ setMethodS3("doGCRMA", "character", function(dataSet, ..., verbose=FALSE) {
 
 ############################################################################
 # HISTORY:
+# 2013-05-02
+# o Removed argument 'ram' in favor of aroma option 'memory/ram'.
 # 2011-11-10
-# o ROBUSTNESS: doGCRMA() is now guaranteed to undo any changes of 
+# o ROBUSTNESS: doGCRMA() is now guaranteed to undo any changes of
 #   the CDF of the data set, e.g. if there is a user interrupt.
 # 2011-04-07
 # o Added argument 'drop'.
@@ -211,7 +314,7 @@ setMethodS3("doGCRMA", "character", function(dataSet, ..., verbose=FALSE) {
 # o Now doGCRMA() automagically makes sure that the default CDF is used
 #   in the GcRmaBackgroundCorrection step, while use a custom CDF
 #   everywhere else if set.
-# o Added argument 'type' to doGCRMA() which is passed to 
+# o Added argument 'type' to doGCRMA() which is passed to
 #   QuantileNormalization().
 # 2010-08-14
 # o Created from doRMA.R.
